@@ -1,35 +1,19 @@
 import datetime
 import functools
 import json
-import sys
-
-from requests import HTTPError
-
-try:
-    import textwrap
-    textwrap.indent
-except AttributeError:  # undefined function (wasn't added until Python 3.3)
-    def indent(text, prefix, predicate=None):
-        if predicate is None:
-            def predicate(line):
-                return line.strip()
-
-        def prefixed_lines():
-            for line in text.splitlines(True):
-                yield (prefix + line if predicate(line) else line)
-
-        return ''.join(prefixed_lines())
-else:
-    def indent(text, prefix):
-        return textwrap.indent(text, prefix)
+import textwrap
+from typing import Dict, Union
+from urllib.parse import urlparse
 
 import requests
+from requests import HTTPError
 from requests.auth import HTTPBasicAuth
-from six.moves.urllib.parse import urlparse
 
 from fineract.exceptions import BadCredentialsException, ResourceNotFoundException, BadArgsException, FineractException
 
-at_least_python3 = sys.hexversion >= 0x03000000
+
+def indent(text, prefix):
+    return textwrap.indent(text, prefix)
 
 
 class RequestHandler:
@@ -40,7 +24,7 @@ class RequestHandler:
             'Fineract-Platform-TenantId': tenant
         }
         self.__locale = 'en'
-        self.__date_format = 'yyyy-MM-dd'
+        self.__date_format = 'yyyy-MM-dd HH:mm:ss'
         self.__auth = HTTPBasicAuth(username, password)
         self.__timeout = timeout
         o = urlparse(base_url)
@@ -54,7 +38,7 @@ class RequestHandler:
         self.__format_json = functools.partial(json.dumps, indent=2, sort_keys=True)
         self.__indent = functools.partial(indent, prefix='  ')
 
-    def make_request(self, method, url, **kwargs):
+    def make_request(self, method, url, **kwargs) -> Union[Dict, bytes]:
         url = self.__base_url + url
         kwargs['auth'] = self.__auth
         kwargs['headers'] = {x: self.__headers[x] for x in self.__headers.keys()}
@@ -62,6 +46,10 @@ class RequestHandler:
             del kwargs['headers']['Content-Type']
             del kwargs['content_type']
 
+        if 'accept' in kwargs:
+            kwargs['headers']['accept'] = kwargs['accept']
+            del kwargs['accept']
+
         # kwargs['verify'] = self.__ssl_check
         kwargs = self.__inject_extras(kwargs)
         kwargs['method'] = method
@@ -96,7 +84,7 @@ class RequestHandler:
         else:
             return res.json() if not is_file else res.content
 
-    def format_request(self, req):
+    def format_request(self, req) -> str:
         headers = '\n'.join('{}: {}'.format(k, v) for k, v in req.headers.items())
         content_type = req.headers.get('Content-Type', '')
         if 'application/json' in content_type and req.body is not None:
@@ -128,7 +116,7 @@ class RequestHandler:
         )
         return s
 
-    def format_response(self, resp):
+    def format_response(self, resp) -> str:
         headers = '\n'.join('{}: {}'.format(k, v) for k, v in resp.headers.items())
         content_type = resp.headers.get('Content-Type', '')
         if 'application/json' in content_type:
@@ -159,7 +147,7 @@ class RequestHandler:
         )
         return s
 
-    def __inject_extras(self, kwargs):
+    def __inject_extras(self, kwargs) -> dict:
         payload = None
         if 'data' in kwargs:
             payload = kwargs['data']
@@ -170,7 +158,7 @@ class RequestHandler:
         if payload:
             extras = {}
             for key in payload.keys():
-                if 'date' in key.lower() and isinstance(payload[key], datetime.datetime):
+                if isinstance(payload[key], datetime.datetime):
                     extras['locale'] = self.__locale
                     extras['dateFormat'] = self.__date_format
                     extras[key] = self.__date_string(payload[key])
@@ -186,10 +174,11 @@ class RequestHandler:
         return kwargs
 
     @staticmethod
-    def __date_string(date):
-        return date.strftime('%Y-%m-%d')
+    def __date_string(date) -> str:
+        return date.strftime('%Y-%m-%d %H:%M:%S')
 
-    def __create_err_message(self, data):
+    @staticmethod
+    def __create_err_message(data) -> str:
         if 'defaultUserMessage' in data:
             message = data['defaultUserMessage']
             if 'errors' in message:
@@ -201,7 +190,8 @@ class RequestHandler:
 
         return message
 
-    def __create_exception(self, status, output):
+    @staticmethod
+    def __create_exception(status, output) -> Union[FineractException]:
         mappings = {
             '400': BadArgsException,
             '401': BadCredentialsException,
